% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dynrModel.R
\name{nobs.dynrModel}
\alias{nobs.dynrModel}
\title{Extract the number of observations for a dynrModel object}
\usage{
\method{nobs}{dynrModel}(object, ...)
}
\arguments{
\item{object}{An unfitted model object}

\item{...}{Further named arguments. Ignored.}
}
\value{
A single number. The total number of observations across all IDs.
}
\description{
Extract the number of observations for a dynrModel object
}
\details{
We return the total number of rows of data, adding up the number of time points for each person. For some purposes, you may want the mean number of observations per person or the number of people instead.  These are not currently supported via \code{nobs}.
}
\examples{
# Create a minimal uncooked model called 'model'
# That is, without esimating parameters
require(dynr)

meas <- prep.measurement(
	values.load=matrix(c(1, 0), 1, 2),
	params.load=matrix(c('fixed', 'fixed'), 1, 2),
	state.names=c("Position","Velocity"),
	obs.names=c("y1"))

ecov <- prep.noise(
	values.latent=diag(c(0, 1), 2),
	params.latent=diag(c('fixed', 'dnoise'), 2),
	values.observed=diag(1.5, 1),
	params.observed=diag('mnoise', 1))

initial <- prep.initial(
	values.inistate=c(0, 1),
	params.inistate=c('inipos', 'fixed'),
	values.inicov=diag(1, 2),
	params.inicov=diag('fixed', 2))

dynamics <- prep.matrixDynamics(
	values.dyn=matrix(c(0, -0.1, 1, -0.2), 2, 2),
	params.dyn=matrix(c('fixed', 'spring', 'fixed', 'friction'), 2, 2),
	isContinuousTime=TRUE)

data(Oscillator)
data <- dynr.data(Oscillator, id="id", time="times", observed="y1")

model <- dynr.model(dynamics=dynamics, measurement=meas,
	noise=ecov, initial=initial, data=data)

# Now get the total number of observations!
nobs(model)
}

